import datetime

from rest_framework import serializers


class BlackListSysRequestSerializer(serializers.Serializer):
    TransID = serializers.RegexField(regex='^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$')
    RequestorID = serializers.CharField()
    DateTime = serializers.DateTimeField(default=datetime.datetime.now(), required=False,
                                         format="%Y-%m-%dT%H:%M:%S.%f+Z")
    # timestamp = serializers.DateTimeField(default=datetime.datetime.now(), format="%y-%m-%dT%H:%M:%S.%f", write_only=True)
    # DateTime = serializers.SerializerMethodField("generate_timestamp")
    #
    # def generate_timestamp(self, obj):
    #     return obj.get('timestamp')



class BlackListRequestSerializer(serializers.Serializer):
    Sequence = serializers.CharField()
    NationalID = serializers.CharField()
    FBNumber = serializers.CharField()
    Birthday = serializers.DateField(format="%Y-%m-%d", required=False, allow_null=True)
    PhoneNumber = serializers.CharField()
    PersonType = serializers.CharField()
    PersonID = serializers.CharField()

class BlackListGetSerializer(serializers.Serializer):
    Sys = BlackListSysRequestSerializer()
    BlackListRequest = BlackListRequestSerializer(many=True)

    def is_valid(self, raise_exception=False):
        validity = super(BlackListGetSerializer, self).is_valid(raise_exception)
        if not validity:
            return validity
        self.data['Sys']['DateTime'] = datetime.datetime.strptime(self.data['Sys']['DateTime'], '%Y-%m-%dT%H:%M:%S.%f+Z')
        return validity


class BlackListSysResponseSerializer(serializers.Serializer):
    TransID = serializers.RegexField(regex='^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$')
    Code = serializers.CharField()
    DateTime = serializers.DateTimeField(default=datetime.datetime.now(), format="%y-%m-%dT%H:%M:%S.%f")
    Description = serializers.CharField(required=False, allow_null=True)


class BlackListResponseSerializer(serializers.Serializer):
    FullName = serializers.CharField()
    NationalID = serializers.CharField()
    FBNumber = serializers.CharField(required=False, allow_null=True)
    FBOwnerID = serializers.CharField(required=False, allow_null=True)
    MobilePhone = serializers.CharField(required=False, allow_null=True)
    HomePhone = serializers.CharField(required=False, allow_null=True)
    Source = serializers.CharField()
    ReasonCode = serializers.CharField()
    Status = serializers.CharField()
    Post_date = serializers.DateField(default=datetime.datetime.now(), format="%y-%m-%d")
    ModifyDate = serializers.DateField(default=datetime.datetime.now(), format="%y-%m-%d")


class BlackListReturnSerializer(serializers.Serializer):
    Sys = BlackListSysResponseSerializer()
    BlackList = BlackListResponseSerializer(required=False, many=True, allow_null=True)
    CustBlackListStatus = serializers.CharField()
    FamBlackListStatus = serializers.CharField()
    CustEMI = serializers.CharField()
    FamEMI = serializers.CharField()
