from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response

from base_app import utils
from base_app.utils import make_dict
from base_app.views import BaseAPIView
from fec_blacklist.conf import settings
from fec_blacklist.constants import BLACKLIST_RETURN_CODES
from fec_blacklist.serializers import (BlackListGetSerializer,
                                       BlackListReturnSerializer)


class CheckBlacklistSync(BaseAPIView):
    permission_classes = (AllowAny,)

    def post(self, request):
        serializer = BlackListGetSerializer(data=request.data)
        if serializer.is_valid():
            response = self.soap_request(settings.BLACKLIST_WSDL,
                                         'CheckBlackList',
                                         data=serializer.data)
            response_serializer = BlackListReturnSerializer(
                data=make_dict(response))
            if response_serializer.is_valid():
                if response_serializer.data.get('Sys').get('Code') == "1":
                    return utils.response(response_serializer.data)
                if response_serializer.data.get('Sys').get('Code') in BLACKLIST_RETURN_CODES.keys():
                    error = BLACKLIST_RETURN_CODES[response_serializer.data.get('Sys').get('Code')]
                    error.update({'type':'t','reason':error.get('message')})
                    return utils.response(response_serializer.data, error=error, code=error['http_status'])
                error = BLACKLIST_RETURN_CODES["unknown_error_code"]
                error.update({'type':'t','reason':error.get('message')})
                return utils.response(response_serializer.data, error=error, code=error['http_status'])
            # Returning Error response
            error = BLACKLIST_RETURN_CODES["unknown_error_code"]
            error.update({'type':'t','reason':'bad response'})
            return utils.response(make_dict(response), error=error)
        error = serializer.errors
        error.update({'type':'s','reason':'bad request'})
        return utils.response(None, status.HTTP_400_BAD_REQUEST, error=error)


class CheckBlacklist(BaseAPIView):
    permission_classes = (AllowAny,)

    def get(self, request):
        pass
